@@ -161,5 +161,8 @@ class ArgumentsCache:
         :param path: Path in the Blob storage where the blob is stored.
         """
         path = path.replace("/tmp/", "")
-        data = __BLOB_STORAGE__.get_blob(path)
+        try:
+            data = __BLOB_STORAGE__.get_blob(path)
+        except RuntimeError as e:
+            raise RuntimeError(f"Failed to retrieve blob from path {path}: {str(e)}")
         return json.loads(data)
