@@ -123,12 +123,10 @@ class EntryPoint:
             module = importlib.import_module(self.module_name)
             func = getattr(module, self.function_name)
             return func(*args, **kwargs)
-
-        elif self.type == JobType.SERVICE:
-            raise NotImplementedError("Service jobs are not yet implemented.")
-
-        elif self.type == JobType.APP:
-            raise NotImplementedError("App jobs are not yet implemented.")
+        else:
+            raise NotImplementedError(
+                f"EntryPoint of type '{self.type}' is not callable."
+            )
 
     def __repr__(self):
         return f"EntryPoint({self.function_name} from {self.module_name}, type={self.type})"
