@@ -459,7 +459,7 @@ class Batch(Job):
             return args
         return {}
 
-    def run(self) -> Tuple[bool, str]:
+    def prepare_args(self) -> None:
         def arg_name(arg: Union[BatchJob, str]) -> str:
             return arg.name if isinstance(arg, BatchJob) else arg
 
@@ -481,6 +481,14 @@ class Batch(Job):
         }
 
         __ARGUMENTS_CACHE__.add_arguments(self.id, args)
+
+    def save(self) -> Tuple[bool, str]:
+        self.prepare_args()
+        return super().save()
+
+    def run(self) -> Tuple[bool, str]:
+        self.prepare_args()
+
         if not self.__local_run and is_dt_installed():
             return super().run()
         else:
